<?xml version="1.0"?>

<!-- REVISION LIST

v5.20		 02.07.2020	Werner Wagner
			Macros bei Baustahl >15mm eingefügt
			Macronamen case-sensitiv angepasst, Schreibweise jetzt wie auf GC
			
-->

<!--define version of xsl, used namespaces, and excluded prefixes ,  (MCS-Scripts is namespace of the Messer C# script) -->
<xsl:stylesheet
			version                 = "1.0"
			xmlns:xsl               = "http://www.w3.org/1999/XSL/Transform"
			xmlns:msxsl             = "urn:schemas-microsoft-com:xslt"
			xmlns:MCS-Scripts       = "MCS-Scripts"
			exclude-result-prefixes = "msxsl" >
	<!--set the version as parameter: defines machine-type and version of needed output from OmniBevel -->
	<xsl:param name="version" select="Machine-Skew-Release" />

	<!--C# script section, foe functions, not programmable or too complicated to program in xslt and XPath -->
	<msxsl:script language="C#" implements-prefix="MCS-Scripts">
    <![CDATA[
	    
    public string DecimalSeparator = System.Globalization.CultureInfo.CurrentCulture.NumberFormat.NumberDecimalSeparator;

    public int LineNumber = 0;	// actual line number, in the moment only used for Nxxx numbering of the piercing points

        public string ExtractFileName (string FullName)
        {
            string result;
            result = System.IO.Path.GetFileName(FullName);
            return result;
        }
        
		public double xminContour, xmaxContour, yminContour, ymaxContour;
									// actual borders of contours, used by calculation of contour diameter

		//---------------------------------------------------------------------------------------
		// GetLineNumber delivers the next linenumber with preceding zeros

		public string GetLineNumber ()
		{
			++ LineNumber;

			return LineNumber .ToString ();
		}

		//-----------------------------------------------------------------------------------------
		// MakeMultiLines replaces ", " in a string by CR/LF. F.h needed to output export parameters as program footer or header etc.

		public string MakeMultiLines (string String)
		{
			return String .Replace (", ", "\r\n");
		}

        public string GetDigitsNumber (string Variable)
        {
          switch (Variable)
          {
            case "0": return "#0.00";
            case "1": return "#0.000";
            case "2": return "#0.000000";
          }

          return "#0.000";
        }

		//-----------------------------------------------------------------------------------------
		// GetRotationAngleForLine return the positive angle of a line in degrees
		// (the paramter m_NodeList must contain as first element aline)

		public string GetRotationAngleForLine (XPathNodeIterator m_NodeList)
		{
			m_NodeList .MoveNext ();
			XPathNavigator m_Path = m_NodeList .Current;

			XPathNodeIterator m_ChildNodeList;

			m_ChildNodeList = m_Path .Select ("Point-A/X"); m_ChildNodeList .MoveNext ();
			double x1 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));    // replace . by , to allow Conversion

			m_ChildNodeList = m_Path .Select ("Point-A/Y"); m_ChildNodeList .MoveNext ();
			double y1 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

			m_ChildNodeList = m_Path .Select ("Point-B/X"); m_ChildNodeList .MoveNext ();
			double x2 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

			m_ChildNodeList = m_Path .Select ("Point-B/Y"); m_ChildNodeList .MoveNext ();
			double y2 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

			double	angle = Math .Atan2 (y2-y1, x2-x1) * 57.295779513082;     //57.295779513082 = 180/PI

			while (angle < 0.0)
				angle += 360.0;

			return angle .ToString ("#0.000") .Replace (DecimalSeparator, ".");		// return angle with 3 decimals and decimal point
		}

		//-----------------------------------------------------------------------------------------
		// GetRotationAngleForArch return the positive angle of a line in degrees
		// (the paramter m_NodeList must contain as first element aline)

		public string GetRotationAngleForArch (XPathNodeIterator m_NodeList, string Choice)
		{
			m_NodeList .MoveNext ();
			XPathNavigator m_Path = m_NodeList .Current;

			XPathNodeIterator m_ChildNodeList;

			m_ChildNodeList = m_Path .Select ("Point-A/X"); m_ChildNodeList .MoveNext ();
			double x1 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));   // replace . by , to allow Conversion

			m_ChildNodeList = m_Path .Select ("Point-A/Y"); m_ChildNodeList .MoveNext ();
			double y1 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

			m_ChildNodeList = m_Path .Select ("Center-Relativ/X"); m_ChildNodeList .MoveNext ();
			double xc = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

			m_ChildNodeList = m_Path .Select ("Center-Relativ/Y"); m_ChildNodeList .MoveNext ();
			double yc = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

			m_ChildNodeList = m_Path .Select ("Point-B/X"); m_ChildNodeList .MoveNext ();
			double x2 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

			m_ChildNodeList = m_Path .Select ("Point-B/Y"); m_ChildNodeList .MoveNext ();
			double y2 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

			xc = x1+xc;
			yc = y1+yc;

			double	angle = 0.0;

			if (Choice == "For-Point-A")
				angle = Math .Atan2 (y1-yc, x1-xc) * 57.295779513082;         //57.295779513082 = 180/PI

			if (Choice == "For-Point-B")
				angle = Math .Atan2 (y2-yc, x2-xc) * 57.295779513082;         //57.295779513082 = 180/PI

			m_ChildNodeList = m_Path .Select ("Direction"); m_ChildNodeList .MoveNext ();

			if (m_ChildNodeList .Current .Value == "CW")
				angle -= 90.0;

			if (m_ChildNodeList .Current .Value == "CCW")
				angle += 90.0;

			while (angle < 0.0)
				angle += 360.0;

			return angle .ToString ("#0.000") .Replace (DecimalSeparator, ".");         // return angle with 3 decimals and decimal point
		}

		//-----------------------------------------------------------------------------------------
		// ExtractToolNumber extracts two number symbols those define cutting tool in NC-program.

		public string ExtractToolNumber (string String)
		{
			if (String .Length <= 0)
				return "00";

			int	ToolPosition = String .ToUpper () .LastIndexOf (" T");

			if (ToolPosition > 0)
			{
				string ToolString = String .Substring (ToolPosition + 2);

				return ToolString .Substring (0, ToolString .IndexOf (", "));
			}

			return "00";
		}

		//-----------------------------------------------------------------------------------------
		// GetContourDiameter return the positive diameter angle of next, including both offsets.
		// (the paramter m_NodeList for function 'UpdateContourBorders' must contain as first element aline)

		public string InitiateContourBorders ()
		{
			xminContour = yminContour = +1.0e+30;
			xmaxContour = ymaxContour = -1.0e+30;

			return "";
		}

		public string UpdateContourBorders (XPathNodeIterator m_NodeList)
		{
			int count=0;

			while (m_NodeList .MoveNext ())
			{
				XPathNavigator m_Path = m_NodeList .Current;

				if (m_Path .Name != "Line" && m_Path .Name != "Arch")
					break;

				count ++;

				XPathNodeIterator m_ChildNodeList;

				m_ChildNodeList = m_Path .Select ("Point-A/X"); m_ChildNodeList .MoveNext ();
				double x1 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

				m_ChildNodeList = m_Path .Select ("Point-A/Y"); m_ChildNodeList .MoveNext ();
				double y1 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

				xminContour = Math.Min(xminContour, x1);
				yminContour = Math.Min(yminContour, y1);

				xmaxContour = Math.Max(xmaxContour, x1);
				ymaxContour = Math.Max(ymaxContour, y1);

				m_ChildNodeList = m_Path .Select ("Point-B/X"); m_ChildNodeList .MoveNext ();
				double x2 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

				m_ChildNodeList = m_Path .Select ("Point-B/Y"); m_ChildNodeList .MoveNext ();
				double y2 = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));

				xminContour = Math.Min(xminContour, x2);
				yminContour = Math.Min(yminContour, y2);

				xmaxContour = Math.Max(xmaxContour, x2);
				ymaxContour = Math.Max(ymaxContour, y2);
			}

			return "";
		}

		public string GetContourDiameter (string minDiameter, string minSpeedFactor, string maxDiameter, string maxSpeedFactor)
		{
			if (xminContour > xmaxContour || yminContour > ymaxContour)
				return "1.000";

			double Diameter = 0.0;

			Diameter += (xmaxContour-xminContour) * (xmaxContour-xminContour);
			Diameter += (ymaxContour-yminContour) * (ymaxContour-yminContour);

			Diameter = Math.Sqrt(Diameter);

			double dmin = Convert .ToDouble (minDiameter .Replace (".", DecimalSeparator));
			double dmax = Convert .ToDouble (maxDiameter .Replace (".", DecimalSeparator));

			double pmin = Convert .ToDouble (minSpeedFactor .Replace (".", DecimalSeparator)) * 0.01;
			double pmax = Convert .ToDouble (maxSpeedFactor .Replace (".", DecimalSeparator)) * 0.01;

			if (dmax <= dmin)
				return "1.000";

			if (Diameter <= dmin)
				return pmin .ToString ("#0.000") .Replace (DecimalSeparator, ".");

			if (Diameter >= dmax)
				return pmax .ToString ("#0.000") .Replace (DecimalSeparator, ".");

			double pcur = pmin + (Diameter - dmin) / (dmax - dmin) * (pmax-pmin);

			return pcur .ToString ("#0.000") .Replace (DecimalSeparator, ".");
		}

		Array VariablesBuffer = new string [64];

		//-----------------------------------------------------------------------------------------
		// CheckAndUpdateTextVariables returns 'true', when Label earlier was not defined to Global
		// Control decription (%%V{}), else 'false'. ClearTextVariables initiates the Label storage.

		public string ClearTextVariables ()
		{
			Array.Clear (VariablesBuffer, 0, 64); return "";
		}

		public string CheckAndUpdateTextVariables (string Label)
		{
			if (Array.IndexOf(VariablesBuffer, Label) >= 0 || Array.IndexOf(VariablesBuffer, null) < 0)
				return "false";

			int LastIndex = Array.IndexOf(VariablesBuffer, null);

			VariablesBuffer.SetValue(Label, LastIndex); return "true";
		}

		//-----------------------------------------------------------------------------------------
		// DefinitionOfBindingPoint calculates positions of start and finish points for text output.
		// It's posiible only for REA-tool, OmniScript-tool must ignore this calculation.

		static double xLabelStartPosition,  yLabelStartPosition;
		static double xLabelFinishPosition, yLabelFinishPosition;

		public string DefinitionOfBindingPoint (XPathNodeIterator m_TextNodes)
		{
			m_TextNodes .MoveNext ();
			XPathNavigator m_Path = m_TextNodes .Current;

			XPathNodeIterator m_ChildNodeList;

			m_ChildNodeList = m_Path .Select ("Label");

			xLabelStartPosition  = yLabelStartPosition  = 0.0;
			xLabelFinishPosition = yLabelFinishPosition = 0.0;

			string Label = "";

			if (m_ChildNodeList .MoveNext ())
				Label = m_ChildNodeList .Current .Value;

			if (Label.Length <= 0)
				return "";

			double xo = 0.0, yo = 0.0, xn = 0.0, yn = 0.0, xsize = 0.0, ysize = 27.0, angle = 0.0;

			m_ChildNodeList = m_Path .Select ("Point/X");

			if (m_ChildNodeList .MoveNext ())
				xo = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));   // replace . by , to allow Conversion

			m_ChildNodeList = m_Path .Select ("Point/Y");

			if (m_ChildNodeList .MoveNext ())
				yo = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));   // replace . by , to allow Conversion

			m_ChildNodeList = m_Path .Select ("Finish-Point/X");

			if (m_ChildNodeList .MoveNext ())
				xn = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));   // replace . by , to allow Conversion

			m_ChildNodeList = m_Path .Select ("Finish-Point/Y");

			if (m_ChildNodeList .MoveNext ())
				yn = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));   // replace . by , to allow Conversion

			m_ChildNodeList = m_Path .Select ("Text-Height");

			if (m_ChildNodeList .MoveNext ())
				ysize = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));   // replace . by , to allow Conversion

			if (ysize<12.0)
			{
				xsize = 8.0; ysize = 9.0;
			}

			if (ysize>=12.0 && ysize<18.0)
			{
				xsize = 11.0; ysize = 12.0;
			}

			if (ysize>=18.0 && ysize<24.0)
			{
				xsize = 13.0; ysize = 18.0;
			}

			if (ysize>=24.0 && ysize<27.0)
			{
				xsize = 16.0; ysize = 24.0;
			}

			if (ysize>=27.0)
			{
				xsize = 20.0; ysize = 27.0;
			}

			m_ChildNodeList = m_Path .Select ("Text-Rotation");

			if (m_ChildNodeList .MoveNext ())
				angle = Convert .ToDouble (m_ChildNodeList .Current .Value .Replace (".", DecimalSeparator));   // replace . by , to allow Conversion

			m_ChildNodeList = m_Path .Select ("Text-Binder-Position");

			double dx = 0.0, dy = 0.0;

			if (m_ChildNodeList .MoveNext ())
				switch (m_ChildNodeList .Current .Value)
				{
					case "Left-Bottom":		dx = 0.0;                    dy = 0.0; break;
					case "Middle-Bottom":	dx = 0.5*xsize*Label.Length; dy = 0.0; break;
					case "Right-Bottom":	dx =     xsize*Label.Length; dy = 0.0; break;
					case "Left-Middle":		dx = 0.0;                    dy = 0.5*ysize; break;
					case "Center":			dx = 0.5*xsize*Label.Length; dy = 0.5*ysize; break;
					case "Right-Middle":	dx =     xsize*Label.Length; dy = 0.5*ysize; break;
					case "Left-Top":		dx = 0.0;                    dy = ysize; break;
					case "Middle-Top":		dx = 0.5*xsize*Label.Length; dy = ysize; break;
					case "Right-Top":		dx =     xsize*Label.Length; dy = ysize; break;
				}

			m_ChildNodeList = m_Path .Select ("Text-Reverse-Drawing");

			bool TextReverseDrawing = false;

			if (m_ChildNodeList .MoveNext ())
				TextReverseDrawing = true;

			double len = Math.Sqrt ( (xn-xo) * (xn-xo) + (yn-yo) * (yn-yo) );

			if (len < xsize)
			{
				if (TextReverseDrawing)
					angle = TextReverseDrawing ? Math.PI - angle*Math.PI/180.0 : + angle*Math.PI/180.0;
			}
			else
				angle = Math.Atan2 (yn-yo, xn-xo);

			double dxo = TextReverseDrawing ? -30.0 - xsize*Label.Length + dx : -22.0 - dx;
			double dyo = -dy;

			xLabelStartPosition  = xo + dxo * Math.Cos(angle) - dyo * Math.Sin(angle);
			yLabelStartPosition  = yo + dxo * Math.Sin(angle) + dyo * Math.Cos(angle);

			double dxn = TextReverseDrawing ? +dx : xsize*Label.Length - dx;
			double dyn = -dy;

			xLabelFinishPosition  = xo + dxn * Math.Cos(angle) - dyn * Math.Sin(angle);
			yLabelFinishPosition  = yo + dxn * Math.Sin(angle) + dyn * Math.Cos(angle);

			return "";
		}

		public double xGetLabelStartPosition ()
		{
			return xLabelStartPosition;
		}

		public double yGetLabelStartPosition ()
		{
			return yLabelStartPosition;
		}

		public double xGetLabelFinishPosition ()
		{
			return xLabelFinishPosition;
		}

		public double yGetLabelFinishPosition ()
		{
			return yLabelFinishPosition;
		}
	]]>
	</msxsl:script>

	<!-- we give out text format that is not indented(no XML), and we strip blanks in all elements  -->
	<xsl:output method="text" />

	<xsl:strip-space elements="*" />

	<!-- the template for the Root-Configuration contains the decription of the export-parameters for this export-transformation -->
	<!-- details see seperate document -->
	<xsl:template match="Root-Configuration">
		<xsl:element name="Parameters" namespace="urn:MCS-IEParameters">
          <xsl:element name="CategoryInterfaceParameters" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Interface parameter</xsl:text><xsl:text xml:lang="zh">界面参数</xsl:text><xsl:text xml:lang="pt">Parâmetro de interface</xsl:text><xsl:text xml:lang="fr">Interface-paramètres</xsl:text><xsl:text xml:lang="es">Parámetro de interfaz</xsl:text><xsl:text xml:lang="de">Schnittstellen-Parameter</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">CATEGORY</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0002" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0002</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Name of export filter</xsl:text><xsl:text xml:lang="zh">导出过滤器名称</xsl:text><xsl:text xml:lang="pt">Nome do filtro de exportação</xsl:text><xsl:text xml:lang="fr">Nom du filtre d'export</xsl:text><xsl:text xml:lang="es">Nombre de filtro de exportación</xsl:text><xsl:text xml:lang="de">Name des Export-Filters</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">
              <xsl:text xml:lang="en">Standard NC codes</xsl:text><xsl:text xml:lang="zh">标准NC代码</xsl:text><xsl:text xml:lang="pt">Padrão de códigos  NC</xsl:text><xsl:text xml:lang="fr">Code-NC standard</xsl:text><xsl:text xml:lang="es">Códigos NC estándar</xsl:text><xsl:text xml:lang="de">Standard-NC-Codes</xsl:text>
            </xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0001" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0001</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Default extension for NC codes</xsl:text><xsl:text xml:lang="zh">机器NC-代码的缺省扩展名</xsl:text><xsl:text xml:lang="pt">Extensão padrão para códigos NC</xsl:text><xsl:text xml:lang="fr">Extension par défaut pour codes-NC</xsl:text><xsl:text xml:lang="es">Extensión por defecto para códigos NC</xsl:text><xsl:text xml:lang="de">Vorgabe-Erweiterung für NC-Codes</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">TXT</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0003" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0003</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Number of digits after decimal point in coordinate value</xsl:text><xsl:text xml:lang="zh">小数点后面的数在坐标中的值</xsl:text><xsl:text xml:lang="pt">Número de dígitos das coordenadas</xsl:text><xsl:text xml:lang="fr">Positions après virgule dans valeur de coordonnées</xsl:text><xsl:text xml:lang="es">Número de decimales en las coordenadas</xsl:text><xsl:text xml:lang="de">Anzahl der Nachkommastellen im Koordinatenwert</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">SELECTION</xsl:attribute>
            <xsl:attribute name="value">1</xsl:attribute>
            <xsl:attribute name="selections">
              <xsl:text xml:lang="en">2|0|3|1|6|2</xsl:text>
            </xsl:attribute>
          </xsl:element>

          <xsl:element name="CategoryNcSpecificatons" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">NC specifications</xsl:text><xsl:text xml:lang="zh">NC规范说明</xsl:text><xsl:text xml:lang="pt">NC especificações</xsl:text><xsl:text xml:lang="fr">Spécifications-NC</xsl:text><xsl:text xml:lang="es">Especificaciones de NC</xsl:text><xsl:text xml:lang="de">NC-Spezifikationen</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">CATEGORY</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0011" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0011</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">NC-program header</xsl:text><xsl:text xml:lang="zh">NC-程序头</xsl:text><xsl:text xml:lang="pt">Cabeçalho do programa-NC</xsl:text><xsl:text xml:lang="fr">En-tête du programme-NC</xsl:text><xsl:text xml:lang="es">Encabezado de programa NC</xsl:text><xsl:text xml:lang="de">NC-Programmkopf</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">G162, G116 A1 C2, G141, G237, #CS ON [V.A.ABS.X,V.A.ABS.Y,0,0,0,V.E.ROTATION], G90 G00 A0.00 C0.00, G90, M190, #KIN ID[33], #TRAFO ON</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0012" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0012</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">NC-program footer</xsl:text><xsl:text xml:lang="zh">NC-程序尾</xsl:text><xsl:text xml:lang="pt">Rodapé do programa-NC</xsl:text><xsl:text xml:lang="fr">Pied de page du programme-NC</xsl:text><xsl:text xml:lang="es">Pie de página de programa NC</xsl:text><xsl:text xml:lang="de">NC-Programmfußzeile</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">G90 G00 A0.00 C0.00, #TRAFO OFF, M64, T0, M65, #CS OFF, M30</xsl:attribute>
          </xsl:element>

          <xsl:element name="BlockContourSmoothing" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Contour smoothing</xsl:text><xsl:text xml:lang="pt">Suavisar contorno</xsl:text><xsl:text xml:lang="fr">Egalisation contour</xsl:text><xsl:text xml:lang="es">Suavizado de contornos</xsl:text><xsl:text xml:lang="de">Konturglättung</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">BLOCK_OF_PARAMETER</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0041" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0041</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Enable contour smoothing for cutting process</xsl:text><xsl:text xml:lang="pt">Ativar suavidade de contorno para processo de corte</xsl:text><xsl:text xml:lang="fr">Activer égalisation contour pour procédé de coupage</xsl:text><xsl:text xml:lang="es">Activar suavizado de contornos para proceso de corte</xsl:text><xsl:text xml:lang="de">Konturglättung für Schneidprozesse aktivieren</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">SELECTION</xsl:attribute>
            <xsl:attribute name="value">0</xsl:attribute>
            <xsl:attribute name="selections">
              <xsl:text xml:lang="en">Yes|1|No|0</xsl:text><xsl:text xml:lang="zh">是|1|否|0</xsl:text><xsl:text xml:lang="pt">Sim|1|Não|0</xsl:text><xsl:text xml:lang="fr">Oui|1|Non|0</xsl:text><xsl:text xml:lang="es">Sí|1|No|0</xsl:text><xsl:text xml:lang="de">Ja|1|Nein|0</xsl:text>
            </xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0042" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0042</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Enable contour smoothing for marking process</xsl:text><xsl:text xml:lang="pt">Ativar suavidade de contorno para processo de marcação</xsl:text><xsl:text xml:lang="fr">Activer égalisation contour pour procédés de marquage</xsl:text><xsl:text xml:lang="es">Activar suavizado de contornos para proceso de marcado</xsl:text><xsl:text xml:lang="de">Konturglättung für Markierprozesse aktivieren</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">SELECTION</xsl:attribute>
            <xsl:attribute name="value">0</xsl:attribute>
            <xsl:attribute name="selections">
              <xsl:text xml:lang="en">Yes|1|No|0</xsl:text><xsl:text xml:lang="zh">是|1|否|0</xsl:text><xsl:text xml:lang="pt">Sim|1|Não|0</xsl:text><xsl:text xml:lang="fr">Oui|1|Non|0</xsl:text><xsl:text xml:lang="es">Sí|1|No|0</xsl:text><xsl:text xml:lang="de">Ja|1|Nein|0</xsl:text>
            </xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0049" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0049</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Permissible abnormality for contour smoothing</xsl:text><xsl:text xml:lang="pt">Anormalidade permissível para suavidade de contorno</xsl:text><xsl:text xml:lang="fr">Ecart toléré pour égalisation de contour</xsl:text><xsl:text xml:lang="es">Anomalía permisible para suavizado de contornos</xsl:text><xsl:text xml:lang="de">Zulässige Abweichung bei der Konturglättung</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">SELECTION</xsl:attribute>
            <xsl:attribute name="value">1</xsl:attribute>
            <xsl:attribute name="selections">0.1 mm|0|0.2 mm|1|0.3 mm|2|0.4 mm|3|0.5 mm|4|0.6 mm|5|0.8 mm|6|1.0 mm|7</xsl:attribute>
          </xsl:element>

          <xsl:element name="BlockSpeedReduction" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Speed reduction for bevel contours, range of smallest to largest vector length</xsl:text><xsl:text xml:lang="pt">Redução de velocidade para os contornos de conexão de chanfro</xsl:text><xsl:text xml:lang="fr">Réduction vitesse pour contours de chanfrein</xsl:text><xsl:text xml:lang="es">Reducción de velocidad para contornos de bisel</xsl:text><xsl:text xml:lang="de">Geschwindigkeitsreduzierung für Fasenkonturen</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">BLOCK_OF_PARAMETER</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0071" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0071</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Enable speed reduction for bevel cutting</xsl:text><xsl:text xml:lang="pt">Ativar redução de velocidade para corte de chanfro</xsl:text><xsl:text xml:lang="fr">Activer réduction vitesse pour coupe de chanfrein</xsl:text><xsl:text xml:lang="es">Activar reducción de velocidad para corte de bisel</xsl:text><xsl:text xml:lang="de">Aktiviere Geschwindigkeitsreduzierung für Fasenschnitte</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">SELECTION</xsl:attribute>
            <xsl:attribute name="value">0</xsl:attribute>
            <xsl:attribute name="selections">
              <xsl:text xml:lang="en">Yes|1|No|0</xsl:text><xsl:text xml:lang="zh">是|1|否|0</xsl:text><xsl:text xml:lang="pt">Sim|1|Não|0</xsl:text><xsl:text xml:lang="fr">Oui|1|Non|0</xsl:text><xsl:text xml:lang="es">Sí|1|No|0</xsl:text><xsl:text xml:lang="de">Ja|1|Nein|0</xsl:text>
            </xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0072" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0072</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Smallest vector length to use while speed reduction</xsl:text><xsl:text xml:lang="pt">Diâmetro limite para os menores contornos</xsl:text><xsl:text xml:lang="fr">Diamètre limite pour contours minimaux</xsl:text><xsl:text xml:lang="es">Límite de diámetro para contornos más pequeños</xsl:text><xsl:text xml:lang="de">Grenzdiagonale für kleinste Konturen</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">DOUBLE</xsl:attribute>
            <xsl:attribute name="value">1.000</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0073" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0073</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Reduced speed for smallest contours, in percentage to origin</xsl:text><xsl:text xml:lang="pt">Redução de velocidade para os contornos menores, em percentagem</xsl:text><xsl:text xml:lang="fr">Réduction de vitesse en pour cent pour contours min.</xsl:text><xsl:text xml:lang="es">Reducción de velocidad para los contornos más pequeños, en porcentaje</xsl:text><xsl:text xml:lang="de">Geschwindigkeitsreduzierung für kleinste Konturen in Prozent</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">DOUBLE</xsl:attribute>
            <xsl:attribute name="value">50.000</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0074" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0074</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Largest vector length to use while speed reduction</xsl:text><xsl:text xml:lang="pt">Diâmetro limite para os maiores contornos</xsl:text><xsl:text xml:lang="fr">Diamètre limite pour contours maximaux</xsl:text><xsl:text xml:lang="es">Límite de diámetro para contornos más grandes</xsl:text><xsl:text xml:lang="de">Grenzdiagonale für größte Konturen</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">DOUBLE</xsl:attribute>
            <xsl:attribute name="value">50.000</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0075" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0075</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Reduced speed for largest contours, in percentage to origin</xsl:text><xsl:text xml:lang="pt">Redução de velocidade para os contornos maiores, em percentagem</xsl:text><xsl:text xml:lang="fr">Réduction de vitesse en pour cent pour contours max.</xsl:text><xsl:text xml:lang="es">Reducción de velocidad para los contornos más grandes, en porcentaje</xsl:text><xsl:text xml:lang="de">Geschwindigkeitsreduzierung für größte Konturen in Prozent</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">DOUBLE</xsl:attribute>
            <xsl:attribute name="value">100.00</xsl:attribute>
          </xsl:element>

          <xsl:element name="CategoryContourSizeCalculation" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Setting for contours size calculation</xsl:text><xsl:text xml:lang="pt">Configurações para calculação do tamanho do contorno</xsl:text><xsl:text xml:lang="fr">Réglage pour calcul dimension de contour</xsl:text><xsl:text xml:lang="es">Ajuste de cálculo de tamaño de contornos</xsl:text><xsl:text xml:lang="de">Einstellung für Konturgrößenberechnung</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">CATEGORY</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0xFF11" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0xFF11</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Minimum length of large contour</xsl:text><xsl:text xml:lang="pt">Comprimento mínimo de um grande contorno</xsl:text><xsl:text xml:lang="fr">Longueur min. d'un grand contour</xsl:text><xsl:text xml:lang="es">Longitud mínima de contorno grande</xsl:text><xsl:text xml:lang="de">Minimale Länge einer großen Kontur</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">DOUBLE</xsl:attribute>
            <xsl:attribute name="value">10.00</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0xFF12" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0xFF12</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Minimum square of large contour</xsl:text><xsl:text xml:lang="pt">Quadrado mínimo de um grande contorno</xsl:text><xsl:text xml:lang="fr">Carré min. d'un grand contour</xsl:text><xsl:text xml:lang="es">Cuadrado mínimo de contorno grande</xsl:text><xsl:text xml:lang="de">Minimales Quadrat einer großen Kontur</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">DOUBLE</xsl:attribute>
            <xsl:attribute name="value">100.00</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0xFF13" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0xFF13</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Maximum angle change in large contour</xsl:text><xsl:text xml:lang="pt">Alteração máxima do ângulo de um grande contorno</xsl:text><xsl:text xml:lang="fr">Modification max. d'angle dans grand contour</xsl:text><xsl:text xml:lang="es">Cambio de ángulo máximo en contorno grande</xsl:text><xsl:text xml:lang="de">Maximale Winkeländerung einer großen Kontur</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">DOUBLE</xsl:attribute>
            <xsl:attribute name="value">0.10</xsl:attribute>
          </xsl:element>

          <xsl:element name="CategoryCuttingToolDefinitions" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Cutting tool definitions</xsl:text><xsl:text xml:lang="pt">Ferramenta de definições de corte</xsl:text><xsl:text xml:lang="fr">Définitions outil de coupe</xsl:text><xsl:text xml:lang="es">Definiciones de herramienta de corte</xsl:text><xsl:text xml:lang="de">Schneidwerkzeugdefinitionen</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">CATEGORY</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0101" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0101</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to enable straight cutting, tactile for large contours</xsl:text><xsl:text xml:lang="pt">Código para ativar o corte em linha reta, tátil</xsl:text><xsl:text xml:lang="fr">Code pour activer coupe verticale tactile</xsl:text><xsl:text xml:lang="es">Código para activar corte recto, táctil para contornos grandes</xsl:text><xsl:text xml:lang="de">Code zum Aktivieren für senkrecht taktil für große Konturen</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">#TRAFO OFF, M64, T21, M65</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0102" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0102</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to enable bevel cutting, tactile</xsl:text><xsl:text xml:lang="pt">Código para ativar o corte de chanfro, tátil</xsl:text><xsl:text xml:lang="fr">Code pour activer chanfrein tactile</xsl:text><xsl:text xml:lang="es">Código para activar corte de bisel, táctil</xsl:text><xsl:text xml:lang="de">Code zum Aktivieren für Fase taktil</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">M64, T22, M65, #TRAFO ON</xsl:attribute>
          </xsl:element>

          <xsl:element name="CategoryMarkingToolDefinitions" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Marking tool definitions</xsl:text><xsl:text xml:lang="pt">Ferramentas de definição de marcação</xsl:text><xsl:text xml:lang="fr">Définitions outil de marquage</xsl:text><xsl:text xml:lang="es">Definiciones de herramienta de marcado</xsl:text><xsl:text xml:lang="de">Markierwerkzeugdefinitionen</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">CATEGORY</xsl:attribute>
          </xsl:element>

          <xsl:element name="BlockPlasmaMarking" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Plasma marking</xsl:text><xsl:text xml:lang="pt">Marcação de plasma</xsl:text><xsl:text xml:lang="fr">Marquage plasma</xsl:text><xsl:text xml:lang="es">Marcado de plasma</xsl:text><xsl:text xml:lang="de">Plasmamarkieren</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">BLOCK_OF_PARAMETER</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0111" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0111</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Enable plasma marking</xsl:text><xsl:text xml:lang="pt">Ativar marcação de plasma</xsl:text><xsl:text xml:lang="fr">Activer marquage plasma</xsl:text><xsl:text xml:lang="es">Activar marcado de plasma</xsl:text><xsl:text xml:lang="de">Aktiviere Plasmamarkieren</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">SELECTION</xsl:attribute>
            <xsl:attribute name="value">1</xsl:attribute>
            <xsl:attribute name="selections">
              <xsl:text xml:lang="en">Yes|1|No|0</xsl:text><xsl:text xml:lang="zh">是|1|否|0</xsl:text><xsl:text xml:lang="pt">Sim|1|Não|0</xsl:text><xsl:text xml:lang="fr">Oui|1|Non|0</xsl:text><xsl:text xml:lang="es">Sí|1|No|0</xsl:text><xsl:text xml:lang="de">Ja|1|Nein|0</xsl:text>
            </xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0112" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0112</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to enable plasma marking</xsl:text><xsl:text xml:lang="pt">Código para ativar marcação a plasma</xsl:text><xsl:text xml:lang="fr">Code pour activer marquage plasma</xsl:text><xsl:text xml:lang="es">Código para activar marcado de plasma</xsl:text><xsl:text xml:lang="de">Code zum Aktivieren des Plasmamarkierens</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">#TRAFO OFF, M64, T49, M65</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0113" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0113</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to switch on plasma marking</xsl:text><xsl:text xml:lang="pt">Código para ligar marcação de plasma</xsl:text><xsl:text xml:lang="fr">Code pour mettre en service le marquage plasma</xsl:text><xsl:text xml:lang="es">Código para encender marcado de plasma</xsl:text><xsl:text xml:lang="de">Code zum Einschalten des Plasmamarkierens</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">M09</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0114" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0114</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to switch off plasma marking</xsl:text><xsl:text xml:lang="pt">Código para desligar a marcação à plasma </xsl:text><xsl:text xml:lang="fr">Code pour désactiver le marquage plasma</xsl:text><xsl:text xml:lang="es">Código para apagar marcado de plasma</xsl:text><xsl:text xml:lang="de">Code zum Ausschalten des Plasmamarkierens</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">M10</xsl:attribute>
          </xsl:element>

          <xsl:element name="BlockPunchMarking" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Punch marking</xsl:text><xsl:text xml:lang="pt">Marcação por punção</xsl:text><xsl:text xml:lang="fr">Pointage</xsl:text><xsl:text xml:lang="es">Marcado de punzón</xsl:text><xsl:text xml:lang="de">Körnen</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">BLOCK_OF_PARAMETER</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0121" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0121</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Enable punch marking</xsl:text><xsl:text xml:lang="pt">Ativar marcação por punção</xsl:text><xsl:text xml:lang="fr">Activer pointage</xsl:text><xsl:text xml:lang="es">Activar marcado de punzón</xsl:text><xsl:text xml:lang="de">Aktiviere Körnen</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">SELECTION</xsl:attribute>
            <xsl:attribute name="value">0</xsl:attribute>
            <xsl:attribute name="selections">
              <xsl:text xml:lang="en">Yes|1|No|0</xsl:text><xsl:text xml:lang="zh">是|1|否|0</xsl:text><xsl:text xml:lang="pt">Sim|1|Não|0</xsl:text><xsl:text xml:lang="fr">Oui|1|Non|0</xsl:text><xsl:text xml:lang="es">Sí|1|No|0</xsl:text><xsl:text xml:lang="de">Ja|1|Nein|0</xsl:text>
            </xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0122" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0122</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to enable punch marking</xsl:text><xsl:text xml:lang="pt">Código para ativar a marcação por punção</xsl:text><xsl:text xml:lang="fr">Code pour activer le pointage</xsl:text><xsl:text xml:lang="es">Código para activar marcado de punzón</xsl:text><xsl:text xml:lang="de">Code zum Aktivieren des Körnens</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">#TRAFO OFF, M64, T42, M65</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0123" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0123</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to switch on punch marking</xsl:text><xsl:text xml:lang="pt">Código para ligar a marcação por punção</xsl:text><xsl:text xml:lang="fr">Code pour mettre en service le pointage</xsl:text><xsl:text xml:lang="es">Código para encender marcado de punzón</xsl:text><xsl:text xml:lang="de">Code zum Einschalten des Körnens</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">M09</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0124" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0124</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to switch off punch marking</xsl:text><xsl:text xml:lang="pt">Código para desligar a marcação por punção</xsl:text><xsl:text xml:lang="fr">Code pour mettre hors service le pointage</xsl:text><xsl:text xml:lang="es">Código para apagar marcado de punzón</xsl:text><xsl:text xml:lang="de">Code zum Ausschalten des Körnens</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">M10</xsl:attribute>
          </xsl:element>

          <xsl:element name="BlockPowderMarking" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Powder marking</xsl:text><xsl:text xml:lang="pt">Marcação a pó</xsl:text><xsl:text xml:lang="fr">Marquage à la poudre</xsl:text><xsl:text xml:lang="es">Marcado de polvo</xsl:text><xsl:text xml:lang="de">Pulvermarkieren</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">BLOCK_OF_PARAMETER</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0131" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0131</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Enable powder marking</xsl:text><xsl:text xml:lang="pt">Ativar marcação a pó</xsl:text><xsl:text xml:lang="fr">Activer marquage à la poudre</xsl:text><xsl:text xml:lang="es">Activar marcado de polvo</xsl:text><xsl:text xml:lang="de">Aktiviere Pulvermarkieren</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">SELECTION</xsl:attribute>
            <xsl:attribute name="value">0</xsl:attribute>
            <xsl:attribute name="selections">
              <xsl:text xml:lang="en">Yes|1|No|0</xsl:text><xsl:text xml:lang="zh">是|1|否|0</xsl:text><xsl:text xml:lang="pt">Sim|1|Não|0</xsl:text><xsl:text xml:lang="fr">Oui|1|Non|0</xsl:text><xsl:text xml:lang="es">Sí|1|No|0</xsl:text><xsl:text xml:lang="de">Ja|1|Nein|0</xsl:text>
            </xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0132" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0132</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to enable powder marking</xsl:text><xsl:text xml:lang="pt">Código para ativar a marcação a pó</xsl:text><xsl:text xml:lang="fr">Code pour activer le marquage à la poudre</xsl:text><xsl:text xml:lang="es">Código para activar marcado de polvo</xsl:text><xsl:text xml:lang="de">Code zum Aktivieren des Pulvermarkierens</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">#TRAFO OFF, M64, T43, M65</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0133" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0133</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to switch on powder marking</xsl:text><xsl:text xml:lang="pt">Código para ligar a macação de pó</xsl:text><xsl:text xml:lang="fr">Code pour mettre en service le marquage à la puodre</xsl:text><xsl:text xml:lang="es">Código para encender marcado de polvo</xsl:text><xsl:text xml:lang="de">Code zum Einschalten des Pulvermarkierens</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">M09</xsl:attribute>
          </xsl:element>

          <xsl:element name="Param0x0134" namespace="urn:MCS-IEParameters">
            <xsl:attribute name="ID">0x0134</xsl:attribute>
            <xsl:attribute name="name">
              <xsl:text xml:lang="en">Code to switch off powder marking</xsl:text><xsl:text xml:lang="pt">Código para desligar a marcação à pó</xsl:text><xsl:text xml:lang="fr">Code pour mettre hors service le marquage à la poudre</xsl:text><xsl:text xml:lang="es">Código para apagar marcado de polvo</xsl:text><xsl:text xml:lang="de">Code zum Ausschalten des Pulvermarkierens</xsl:text>
            </xsl:attribute>
            <xsl:attribute name="type">TEXT</xsl:attribute>
            <xsl:attribute name="value">M10</xsl:attribute>
          </xsl:element>

		</xsl:element>
	</xsl:template>

	<!-- begin of section with named helper templates that are used from other templates -->
	 
	<xsl:template name="TemplateMove">
		<xsl:param name="ThisX" />
		<xsl:param name="ThisY" />

    <xsl:text>G00 X</xsl:text>
    <xsl:value-of select="format-number($ThisX, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
    <xsl:text> Y</xsl:text>
    <xsl:value-of select="format-number($ThisY, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
    <xsl:text>&#10;</xsl:text>

	</xsl:template>

	<xsl:template name="TemplateLine">
		<xsl:param name="ThisLine" />

		<xsl:if test="$ThisLine/Thickness-Delta">
			<xsl:text>G193 </xsl:text>
		</xsl:if>

        <xsl:text>G01 X</xsl:text>
        <xsl:value-of select="format-number($ThisLine/Point-B/X, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> Y</xsl:text>
        <xsl:value-of select="format-number($ThisLine/Point-B/Y, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />

        <xsl:if test="not( (following::*[1]/@name = 'Join011') and ( (following::*[1]/child::node()[1]/child::node()[2] = 'SkewRadialOF') or (following::*[1]/child::node()[1]/child::node()[2] = 'SkewRadialMF') ) )">
            <xsl:text>&#10;</xsl:text>
        </xsl:if>
  </xsl:template>

	<xsl:template name="TemplateArch">
		<xsl:param name="ThisArch" />

		<xsl:if test="$ThisArch/Direction='CCW'" >
			<xsl:text>G03</xsl:text>
		</xsl:if>
		<xsl:if test="$ThisArch/Direction='CW'" >
			<xsl:text>G02</xsl:text>
		</xsl:if>
		<xsl:text> X</xsl:text>
		<xsl:value-of select="format-number($ThisArch/Point-B/X, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
		<xsl:text> Y</xsl:text>
		<xsl:value-of select="format-number($ThisArch/Point-B/Y, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
		<xsl:text> I</xsl:text>
		<xsl:value-of select="format-number($ThisArch/Center-Relativ/X, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
		<xsl:text> J</xsl:text>
		<xsl:value-of select="format-number($ThisArch/Center-Relativ/Y, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
		<xsl:if test="$ThisArch/Angles/Bevel-Angle">
			<xsl:text> A</xsl:text>
		<xsl:value-of select="format-number($ThisArch/Angles/Bevel-Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
		</xsl:if>
		<xsl:text>&#10;</xsl:text>
	</xsl:template>

	<!-- begin of the Root template, that is the top level transformation -->

	<xsl:template name="SelectMacro">
		<xsl:param name="_Material" />
		<xsl:param name="_Thickness" />
		<xsl:choose>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 1.0 and $_Thickness &lt;= 1.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_1mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 1.5 and $_Thickness &lt;= 2.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_2mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 2.5 and $_Thickness &lt;= 3.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_3mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 3.5 and $_Thickness &lt;= 4.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_4mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 4.5 and $_Thickness &lt;= 5.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_5mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 5.5 and $_Thickness &lt;= 6.9">
				<xsl:text>(%%MACRO Boiler_MildSteel_6mm_90A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 7.0 and $_Thickness &lt;= 8.9">
				<xsl:text>(%%MACRO Boiler_MildSteel_8mm_90A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 9.0 and $_Thickness &lt;= 10.9">
				<xsl:text>(%%MACRO Boiler_MildSteel_10mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 11.0 and $_Thickness &lt;= 13.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_12mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 13.5 and $_Thickness &lt;= 16.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_15mm_160A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 17.5 and $_Thickness &lt;= 22.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_20mm_160A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 22.5 and $_Thickness &lt;= 27.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_25mm_200A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 27.5 and $_Thickness &lt;= 32.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_30mm_280A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 32.5 and $_Thickness &lt;= 37.4">
				<xsl:text>(%%MACRO Boiler_MildSteel_35mm_360A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 37.5 and $_Thickness &lt;= 44.9">
				<xsl:text>(%%MACRO Boiler_MildSteel_40mm_360A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='MILD STEEL' and $_Thickness &gt;= 45.0 and $_Thickness &lt;= 54.9">
				<xsl:text>(%%MACRO Boiler_MildSteel_50mm_360A)&#10;</xsl:text>
			</xsl:when>
<!--			<xsl:when test="$_Material='NICKEL' and $_Thickness &gt;= 4.5 and $_Thickness &lt;= 5.4">
				<xsl:text>(%%MACRO BOILER_NICKEL_5mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='NICKEL' and $_Thickness &gt;= 5.5 and $_Thickness &lt;= 6.9">
				<xsl:text>(%%MACRO BOILER_NICKEL_6mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='NICKEL' and $_Thickness &gt;= 7.5 and $_Thickness &lt;= 8.4">
				<xsl:text>(%%MACRO BOILER_NICKEL_8mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='NICKEL' and $_Thickness &gt;= 9.5 and $_Thickness &lt;= 10.4">
				<xsl:text>(%%MACRO BOILER_NICKEL_10mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='NICKEL' and $_Thickness &gt;= 19 and $_Thickness &lt;= 21">
				<xsl:text>(%%MACRO BOILER_NICKEL_20mm_280A)&#10;</xsl:text>
			</xsl:when>  -->
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 0.8 and $_Thickness &lt;= 1.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_1mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 1.5 and $_Thickness &lt;= 2.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_2mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 2.5 and $_Thickness &lt;= 3.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_3mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 3.5 and $_Thickness &lt;= 4.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_4mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 4.5 and $_Thickness &lt;= 5.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_5mm_60A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 5.5 and $_Thickness &lt;= 6.9">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_6mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 7.0 and $_Thickness &lt;= 8.9">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_8mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 9.0 and $_Thickness &lt;= 10.9">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_10mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 11.0 and $_Thickness &lt;= 13.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_12mm_130A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 13.5 and $_Thickness &lt;= 17.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_15mm_160A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 17.5 and $_Thickness &lt;= 22.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_20mm_160A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 22.5 and $_Thickness &lt;= 27.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_25mm_280A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 27.5 and $_Thickness &lt;= 32.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_30mm_280A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 32.5 and $_Thickness &lt;= 37.4">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_35mm_360A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 37.5 and $_Thickness &lt;= 44.9">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_40mm_360A)&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="$_Material='STAINLESS STEEL' and $_Thickness &gt;= 45.0 and $_Thickness &lt;= 54.9">
				<xsl:text>(%%MACRO Boiler_StainlessSteel_50mm_360A)&#10;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>M30&#10;</xsl:text>
				<xsl:text>ERROR! no macro definition: </xsl:text>
				<xsl:value-of select="$_Material" />
				<xsl:text>, </xsl:text>
				<xsl:value-of select="$_Thickness" />
				<xsl:text>mm&#10;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="Root">
		
		<!-- creating header commentaris and other initialisation of the machine -->
		<xsl:text>(FILENAME      </xsl:text>
		<xsl:value-of select="substring-before(@name,'.xml')" />
		<xsl:text>)&#10;</xsl:text>

		<xsl:text>(PP-VERSION    BOILER-SKEW-SLOW-5.20)&#10;</xsl:text>
        <xsl:text>(RELEASE DATE  2020.07.02)&#10;</xsl:text>

		<xsl:text>(MATERIAL      </xsl:text>
        <xsl:value-of select="/Root/Material/@name" />
        <xsl:text>, </xsl:text>
        <xsl:value-of select="/Root/Material/@type" />
		<xsl:text>)&#10;</xsl:text>

		<xsl:text>(THICKNESS     </xsl:text>
        <xsl:value-of select="format-number(/Root/Thickness/@value, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
		<xsl:text>mm)&#10;</xsl:text>

        <xsl:text>(DATABASE      </xsl:text>
        <xsl:value-of select="MCS-Scripts:ExtractFileName(@database)"/>
        <xsl:text>)&#10;</xsl:text>

		<xsl:text>$IF V.E.ROTATION != 0&#10;</xsl:text>
		<xsl:text>M00 ( plate rotation not allowed !! )&#10;</xsl:text>
		<xsl:text>M30&#10;</xsl:text>
		<xsl:text>$ENDIF&#10;</xsl:text>
		
		<xsl:text>( ==== prepare used process ==== )&#10;</xsl:text>
		<xsl:call-template name="SelectMacro">
			<xsl:with-param name="_Material" select="/Root/Material/@type" />
			<xsl:with-param name="_Thickness" select="/Root/Thickness/@value" />
		</xsl:call-template>

		<xsl:if test="Unit-System/@type='Metric'">
			<xsl:text>G71&#10;</xsl:text>
		</xsl:if>

		<xsl:if test="contains(Unit-System/@type,'Imperial')">
			<xsl:text>G70&#10;</xsl:text>
		</xsl:if>

		<!-- output header datas with ', ' replaced by CR/LF -->
		<xsl:value-of select="MCS-Scripts:MakeMultiLines(Parameter[@ID='0x0011']/@value)" />
		<xsl:text>&#10;</xsl:text>

		<!-- output contour mode if necessary-->
        <xsl:if test="/Root/Parameter[@ID='0x0041']/@value='1' or /Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>#CONTOUR MODE [DEV PATH_DEV=</xsl:text>
          <xsl:choose>
            <xsl:when test="/Root/Parameter[@ID='0x0049']/@value='0'">
              <xsl:text>0.1</xsl:text>
            </xsl:when>
            <xsl:when test="/Root/Parameter[@ID='0x0049']/@value='1'">
              <xsl:text>0.2</xsl:text>
            </xsl:when>
            <xsl:when test="/Root/Parameter[@ID='0x0049']/@value='2'">
              <xsl:text>0.3</xsl:text>
            </xsl:when>
            <xsl:when test="/Root/Parameter[@ID='0x0049']/@value='3'">
              <xsl:text>0.4</xsl:text>
           </xsl:when>
            <xsl:when test="/Root/Parameter[@ID='0x0049']/@value='4'">
             <xsl:text>0.5</xsl:text>
            </xsl:when>
            <xsl:when test="/Root/Parameter[@ID='0x0049']/@value='5'">
             <xsl:text>0.6</xsl:text>
            </xsl:when>
            <xsl:when test="/Root/Parameter[@ID='0x0049']/@value='6'">
              <xsl:text>0.7</xsl:text>
            </xsl:when>
            <xsl:when test="/Root/Parameter[@ID='0x0049']/@value='7'">
              <xsl:text>0.8</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>0.2</xsl:text>
            </xsl:otherwise>
          </xsl:choose>

          <xsl:text> RELEVANT_PATH=0.1]&#10;</xsl:text>
        </xsl:if>
		<!-- creating the NC-Code between header and footer by aplying the other templates to the elements of the xml-file -->
		<xsl:apply-templates/>

		<!-- output footer datas with ', ' replaced by CR/LF -->
		<xsl:value-of select="MCS-Scripts:MakeMultiLines(Parameter[@ID='0x0012']/@value)" />
	</xsl:template>

  <!-- template for all Line elements that are childs of the Root element, this are lines of markng contours -->
  <xsl:template match="Root/Line">
    <xsl:call-template name="TemplateLine">
      <xsl:with-param name="ThisLine" select="." />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="Root/Enable-Marking/Marking-Switch-On/Line">
    <xsl:call-template name="TemplateLine">
      <xsl:with-param name="ThisLine" select="." />
    </xsl:call-template>
  </xsl:template>

  <!-- template for all Arch elements that are childs of the Root element, this are arcs of markng contours -->
  <xsl:template match="Root/Arch">
    <xsl:call-template name="TemplateArch">
      <xsl:with-param name="ThisArch" select="." />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="Root/Enable-Marking/Marking-Switch-On/Arch">
    <xsl:call-template name="TemplateArch">
      <xsl:with-param name="ThisArch" select="." />
    </xsl:call-template>
  </xsl:template>

  <!-- template for SafetyDistance elems in Root uses only for Panel machines, for example Panel-Aker-Braila -->
  <xsl:template match="Root/Safety-Distance">
  </xsl:template>

  <xsl:template match="Root/Enable-Marking/SafetyDistance">
  </xsl:template>

  <!-- template for Enable-Marking elems in Root, uses the sequences stored in the paramters for the different process types -->
  <xsl:template match="Root/Enable-Marking">
    <xsl:choose>
      <xsl:when test="/Root/Parameter[@ID='0x0111']/@value='1' and @process='Plasma'">
        <xsl:text>(%%MACRO Boiler_Mark)&#10;</xsl:text>
        <xsl:value-of select="MCS-Scripts:MakeMultiLines(/Root/Parameter[@ID='0x0112']/@value)" />
        <xsl:text>&#10;</xsl:text>
        <xsl:apply-templates />
        <xsl:text>M64&#10;T00&#10;M65&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="/Root/Parameter[@ID='0x0121']/@value='1' and @process='Punch'">
        <xsl:value-of select="MCS-Scripts:MakeMultiLines(/Root/Parameter[@ID='0x0122']/@value)" />
        <xsl:text>&#10;</xsl:text>
        <xsl:apply-templates />
        <xsl:text>M64&#10;T00&#10;M65&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="/Root/Parameter[@ID='0x0131']/@value='1' and @process='Powder'">
        <xsl:value-of select="MCS-Scripts:MakeMultiLines(/Root/Parameter[@ID='0x0132']/@value)" />
        <xsl:text>&#10;</xsl:text>
        <xsl:apply-templates />
        <xsl:text>M64&#10;T00&#10;M65&#10;</xsl:text>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="Root/Enable-Marking/Marking-Switch-On">

    <xsl:variable name="actual-process" select="@process" />

    <xsl:choose>
      <xsl:when test="/Root/Parameter[@ID='0x0111']/@value='1' and @process='Plasma'">
        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G261&#10;</xsl:text>
        </xsl:if>
        <xsl:value-of select="MCS-Scripts:MakeMultiLines(/Root/Parameter[@ID='0x0113']/@value)" />
        <xsl:text>&#10;</xsl:text>
        <xsl:apply-templates />
        <xsl:value-of select="MCS-Scripts:MakeMultiLines(/Root/Parameter[@ID='0x0114']/@value)" />
        <xsl:text>&#10;</xsl:text>
        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G260&#10;</xsl:text>
        </xsl:if>
      </xsl:when>
      <xsl:when test="/Root/Parameter[@ID='0x0121']/@value='1' and @process='Punch'">
        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G261&#10;</xsl:text>
        </xsl:if>
        <xsl:value-of select="MCS-Scripts:MakeMultiLines(/Root/Parameter[@ID='0x0123']/@value)" />
        <xsl:text>&#10;</xsl:text>
        <xsl:apply-templates />
        <xsl:value-of select="MCS-Scripts:MakeMultiLines(/Root/Parameter[@ID='0x0124']/@value)" />
        <xsl:text>&#10;</xsl:text>
        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G260&#10;</xsl:text>
        </xsl:if>
      </xsl:when>
      <xsl:when test="/Root/Parameter[@ID='0x0131']/@value='1' and @process='Powder'">
        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G261&#10;</xsl:text>
        </xsl:if>
        <xsl:value-of select="MCS-Scripts:MakeMultiLines(/Root/Parameter[@ID='0x0133']/@value)" />
        <xsl:text>&#10;</xsl:text>
        <xsl:apply-templates />
        <xsl:value-of select="MCS-Scripts:MakeMultiLines(/Root/Parameter[@ID='0x0134']/@value)" />
        <xsl:text>&#10;</xsl:text>
        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G260&#10;</xsl:text>
        </xsl:if>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

	<!-- Move elements on the Root elem are the rapid ways to the next marking begin -->
	<xsl:template match="Root/Move">
		<xsl:call-template name="TemplateMove">
			<xsl:with-param name="ThisX" select="X" />
			<xsl:with-param name="ThisY" select="Y" />
		</xsl:call-template>
	</xsl:template>
  
  <xsl:template match="Root/Enable-Marking/Move">
    <xsl:call-template name="TemplateMove">
      <xsl:with-param name="ThisX" select="X" />
      <xsl:with-param name="ThisY" select="Y" />
    </xsl:call-template>
  </xsl:template>

	<!-- The lines and arcs in Offset-before and Offset-after are given out without changes -->
	<xsl:template match="Root/Macro/Offset-before">
		<xsl:apply-templates />
	</xsl:template>

	<xsl:template match="Root/Macro/Offset-after">
		<xsl:apply-templates />
	</xsl:template>

	<xsl:template match="Root/Macro/Offset-before/Line">
		<xsl:call-template name="TemplateLine" >
			<xsl:with-param name="ThisLine" select="." />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="Root/Macro/Offset-after/Line">
		<xsl:call-template name="TemplateLine" >
			<xsl:with-param name="ThisLine" select="." />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="Root/Macro/Offset-before/Arch">
		<xsl:call-template name="TemplateArch" >
			<xsl:with-param name="ThisArch" select="." />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="Root/Macro/Offset-after/Arch">
		<xsl:call-template name="TemplateArch" >
			<xsl:with-param name="ThisArch" select="." />
		</xsl:call-template>
	</xsl:template>

	<!-- lines and arcs of macros are not handled directly here, but in the special templates of the macros -->
	<xsl:template match="Root/Macro/Line">
	</xsl:template>
	<xsl:template match="Root/Macro/Arch">
	</xsl:template>

	<!-- Block-before information and Block-after information is only used during macro output -->
	<xsl:template match="Root/Macro/Block-before">
	</xsl:template>

	<xsl:template match="Root/Macro/Block-after">
	</xsl:template>

	<!-- in SKEW no pre-working (advancing hole-cutting for plan) is used in the moment -->

	<xsl:template match="Root/Macro[@step='pre-working']">
	</xsl:template>

  
  
  
	<!-- section with the templates for the different macros, for differen before/after tools -->

	<xsl:template match="Root/Macro[@step='working']">
	</xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='Start041'][Block-after/Tool='SkewRadialOF']">
    <xsl:text>(... Start of START041/GC-SkewRadialOF macro ...)&#10;</xsl:text>

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=3)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro START041&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[1])='Empty-Element'">
        <xsl:text>Error: Erstes Anschnitt-Element von Makro START041 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[2])='Empty-Element'">
        <xsl:text>Error: Zweites Anschnitt-Element von Makro START041 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[3])='Empty-Element'">
        <xsl:text>Error: Drittes Anschnitt-Element von Makro START041 ist leer&#10;</xsl:text>
      </xsl:when>

      <xsl:otherwise>

        <xsl:value-of select="MCS-Scripts:InitiateContourBorders()" />

        <xsl:if test="/Root/Parameter[@ID='0x0071']/@value='1'">
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(child::Offset-after/*[self::Line or self::Arch])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::*[self::Line or self::Arch or self::Macro])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::Macro[1]/Offset-before/*[self::Line or self::Arch])" />
        </xsl:if>

        <xsl:variable name="SpeedFactor" select="MCS-Scripts:GetContourDiameter(/Root/Parameter[@ID='0x0072']/@value, /Root/Parameter[@ID='0x0073']/@value, /Root/Parameter[@ID='0x0074']/@value, /Root/Parameter[@ID='0x0075']/@value)" />

        <xsl:text>G90 G00 A0 C0&#10;</xsl:text>
        <xsl:text>#TIME 0.1&#10;</xsl:text>

		<xsl:call-template name="SelectMacro">
			<xsl:with-param name="_Material" select="../Material/@type" />
			<xsl:with-param name="_Thickness" select="../Thickness/@value" />
		</xsl:call-template>

        <xsl:value-of select="MCS-Scripts:MakeMultiLines(../Parameter[@ID='0x0102']/@value)" />

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M32&#10;</xsl:text>

        <xsl:text>G00 X</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/X, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> Y</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/Y, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> A0 C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M22&#10;</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Speed">
            <xsl:text>M94 F</xsl:text>
            <xsl:value-of select="format-number(child::Block-after/Speed*$SpeedFactor, '#.0')" />
            <xsl:text>&#10;</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>M93&#10;</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:call-template name="TemplateMove" >
          <xsl:with-param name="ThisX" select="child::*[1]//Point-B/X" />
          <xsl:with-param name="ThisY" select="child::*[1]//Point-B/Y" />
        </xsl:call-template>

        <xsl:if test="child::Block-after/Amperage">
          <xsl:text>V.E.CURRENT=</xsl:text>
          <xsl:value-of select="child::Block-after/Amperage" />
          <xsl:text>&#10;</xsl:text>
        </xsl:if>

        <xsl:if test="/Root/Parameter[@ID='0x0041']/@value='1'">
          <xsl:text>G261&#10;</xsl:text>
        </xsl:if>

        <xsl:text>N</xsl:text>
        <xsl:value-of select="MCS-Scripts:GetLineNumber()" />
        <xsl:text> M07&#10;</xsl:text>

        <xsl:text>G01</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Bevel-Parameters/Angle">
            <xsl:text> A</xsl:text>
			<xsl:value-of select="format-number(child::Block-after/Bevel-Parameters/Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:text> A0</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:text> C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>

        <xsl:if test="name(child::*[2])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[2]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="name(child::*[3])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[3]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:text>M34&#10;</xsl:text>

      </xsl:otherwise>
    </xsl:choose>

    <xsl:apply-templates />

    <xsl:text>(... End of START041/GC-SkewRadialOF macro ...)&#10;</xsl:text>
  </xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='Start041'][Block-after/Tool='SkewRadialMF']">
    <xsl:text>(... Start of START041/GC-SkewRadialMF macro ...)&#10;</xsl:text>

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=3)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro START041&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[1])='Empty-Element'">
        <xsl:text>Error: Erstes Anschnitt-Element von Makro START041 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[2])='Empty-Element'">
        <xsl:text>Error: Zweites Anschnitt-Element von Makro START041 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[3])='Empty-Element'">
        <xsl:text>Error: Drittes Anschnitt-Element von Makro START041 ist leer&#10;</xsl:text>
      </xsl:when>

      <xsl:otherwise>

        <xsl:value-of select="MCS-Scripts:InitiateContourBorders()" />

        <xsl:if test="/Root/Parameter[@ID='0x0071']/@value='1'">
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(child::Offset-after/*[self::Line or self::Arch])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::*[self::Line or self::Arch or self::Macro])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::Macro[1]/Offset-before/*[self::Line or self::Arch])" />
        </xsl:if>

        <xsl:variable name="SpeedFactor" select="MCS-Scripts:GetContourDiameter(/Root/Parameter[@ID='0x0072']/@value, /Root/Parameter[@ID='0x0073']/@value, /Root/Parameter[@ID='0x0074']/@value, /Root/Parameter[@ID='0x0075']/@value)" />

        <xsl:text>G90 G00 A0 C0&#10;</xsl:text>
        <xsl:text>#TIME 0.1&#10;</xsl:text>

		<xsl:call-template name="SelectMacro">
			<xsl:with-param name="_Material" select="../Material/@type" />
			<xsl:with-param name="_Thickness" select="../Thickness/@value" />
		</xsl:call-template>

        <xsl:value-of select="MCS-Scripts:MakeMultiLines(../Parameter[@ID='0x0102']/@value)" />

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M32&#10;</xsl:text>

        <xsl:text>G00 X</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/X, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> Y</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/Y, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> A0 C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M22&#10;</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Speed">
            <xsl:text>M94 F</xsl:text>
            <xsl:value-of select="format-number(child::Block-after/Speed*$SpeedFactor, '#.0')" />
            <xsl:text>&#10;</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>M93&#10;</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:call-template name="TemplateMove" >
          <xsl:with-param name="ThisX" select="child::*[1]//Point-B/X" />
          <xsl:with-param name="ThisY" select="child::*[1]//Point-B/Y" />
        </xsl:call-template>

        <xsl:if test="child::Block-after/Amperage">
          <xsl:text>V.E.CURRENT=</xsl:text>
          <xsl:value-of select="child::Block-after/Amperage" />
          <xsl:text>&#10;</xsl:text>
        </xsl:if>

        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G261&#10;</xsl:text>
        </xsl:if>

        <xsl:text>N</xsl:text>
        <xsl:value-of select="MCS-Scripts:GetLineNumber()" />
        <xsl:text> M07&#10;</xsl:text>

        <xsl:text>G01</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Bevel-Parameters/Angle">
            <xsl:text> A</xsl:text>
			<xsl:value-of select="format-number(child::Block-after/Bevel-Parameters/Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:text> A0</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:text> C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>

        <xsl:if test="name(child::*[2])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[2]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="name(child::*[3])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[3]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:text>M34&#10;</xsl:text>

      </xsl:otherwise>
    </xsl:choose>

    <xsl:apply-templates />

    <xsl:text>(... End of START041/GC-SkewRadialMF macro ...)&#10;</xsl:text>
  </xsl:template>


  <xsl:template match="Root/Macro[@step='working'][@name='Start042'][Block-after/Tool='SkewRadialOF']">
    <xsl:text>(... Start of START042/GC-SkewRadialOF macro ...)&#10;</xsl:text>

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=4)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro START042&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[1])='Empty-Element'">
        <xsl:text>Error: Erstes Anschnitt-Element von Makro START042 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[2])='Empty-Element'">
        <xsl:text>Error: Zweites Anschnitt-Element von Makro START042 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[3])='Empty-Element'">
        <xsl:text>Error: Drittes Anschnitt-Element von Makro START042 ist leer&#10;</xsl:text>
      </xsl:when>

      <xsl:otherwise>

        <xsl:value-of select="MCS-Scripts:InitiateContourBorders()" />

        <xsl:if test="/Root/Parameter[@ID='0x0071']/@value='1'">
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(child::Offset-after/*[self::Line or self::Arch])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::*[self::Line or self::Arch or self::Macro])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::Macro[1]/Offset-before/*[self::Line or self::Arch])" />
        </xsl:if>

        <xsl:variable name="SpeedFactor" select="MCS-Scripts:GetContourDiameter(/Root/Parameter[@ID='0x0072']/@value, /Root/Parameter[@ID='0x0073']/@value, /Root/Parameter[@ID='0x0074']/@value, /Root/Parameter[@ID='0x0075']/@value)" />

        <xsl:text>G90 G00 A0 C0&#10;</xsl:text>
        <xsl:text>#TIME 0.1&#10;</xsl:text>

		<xsl:call-template name="SelectMacro">
			<xsl:with-param name="_Material" select="../Material/@type" />
			<xsl:with-param name="_Thickness" select="../Thickness/@value" />
		</xsl:call-template>

        <xsl:value-of select="MCS-Scripts:MakeMultiLines(../Parameter[@ID='0x0102']/@value)" />

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M32&#10;</xsl:text>

        <xsl:text>G00 X</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/X, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> Y</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/Y, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> A0 C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M22&#10;</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Speed">
            <xsl:text>M94 F</xsl:text>
            <xsl:value-of select="format-number(child::Block-after/Speed*$SpeedFactor, '#.0')" />
            <xsl:text>&#10;</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>M93&#10;</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:call-template name="TemplateMove" >
          <xsl:with-param name="ThisX" select="child::*[1]//Point-B/X" />
          <xsl:with-param name="ThisY" select="child::*[1]//Point-B/Y" />
        </xsl:call-template>

        <xsl:if test="child::Block-after/Amperage">
          <xsl:text>V.E.CURRENT=</xsl:text>
          <xsl:value-of select="child::Block-after/Amperage" />
          <xsl:text>&#10;</xsl:text>
        </xsl:if>

        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G261&#10;</xsl:text>
        </xsl:if>

        <xsl:text>N</xsl:text>
        <xsl:value-of select="MCS-Scripts:GetLineNumber()" />
        <xsl:text> M07&#10;</xsl:text>

        <xsl:text>G01</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Bevel-Parameters/Angle">
            <xsl:text> A</xsl:text>
			<xsl:value-of select="format-number(child::Block-after/Bevel-Parameters/Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:text> A0</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:text> C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>

        <xsl:if test="name(child::*[2])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[2]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="name(child::*[3])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[3]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="name(child::*[4])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[4]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:text>M34&#10;</xsl:text>

      </xsl:otherwise>
    </xsl:choose>

    <xsl:apply-templates />

    <xsl:text>(... End of START042/GC-SkewRadialOF macro ...)&#10;</xsl:text>
  </xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='Start042'][Block-after/Tool='SkewRadialMF']">
    <xsl:text>(... Start of START042/GC-SkewRadialMF macro ...)&#10;</xsl:text>

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=4)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro START042&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[1])='Empty-Element'">
        <xsl:text>Error: Erstes Anschnitt-Element von Makro START042 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[2])='Empty-Element'">
        <xsl:text>Error: Zweites Anschnitt-Element von Makro START042 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[3])='Empty-Element'">
        <xsl:text>Error: Drittes Anschnitt-Element von Makro START042 ist leer&#10;</xsl:text>
      </xsl:when>

      <xsl:otherwise>

        <xsl:value-of select="MCS-Scripts:InitiateContourBorders()" />

        <xsl:if test="/Root/Parameter[@ID='0x0071']/@value='1'">
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(child::Offset-after/*[self::Line or self::Arch])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::*[self::Line or self::Arch or self::Macro])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::Macro[1]/Offset-before/*[self::Line or self::Arch])" />
        </xsl:if>

        <xsl:variable name="SpeedFactor" select="MCS-Scripts:GetContourDiameter(/Root/Parameter[@ID='0x0072']/@value, /Root/Parameter[@ID='0x0073']/@value, /Root/Parameter[@ID='0x0074']/@value, /Root/Parameter[@ID='0x0075']/@value)" />

        <xsl:text>G90 G00 A0 C0&#10;</xsl:text>
        <xsl:text>#TIME 0.1&#10;</xsl:text>

		<xsl:call-template name="SelectMacro">
			<xsl:with-param name="_Material" select="../Material/@type" />
			<xsl:with-param name="_Thickness" select="../Thickness/@value" />
		</xsl:call-template>

        <xsl:value-of select="MCS-Scripts:MakeMultiLines(../Parameter[@ID='0x0102']/@value)" />

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M32&#10;</xsl:text>

        <xsl:text>G00 X</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/X, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> Y</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/Y, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> A0 C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M22&#10;</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Speed">
            <xsl:text>M94 F</xsl:text>
            <xsl:value-of select="format-number(child::Block-after/Speed*$SpeedFactor, '#.0')" />
            <xsl:text>&#10;</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>M93&#10;</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:call-template name="TemplateMove" >
          <xsl:with-param name="ThisX" select="child::*[1]//Point-B/X" />
          <xsl:with-param name="ThisY" select="child::*[1]//Point-B/Y" />
        </xsl:call-template>

        <xsl:if test="child::Block-after/Amperage">
          <xsl:text>V.E.CURRENT=</xsl:text>
          <xsl:value-of select="child::Block-after/Amperage" />
          <xsl:text>&#10;</xsl:text>
        </xsl:if>

        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G261&#10;</xsl:text>
        </xsl:if>

        <xsl:text>N</xsl:text>
        <xsl:value-of select="MCS-Scripts:GetLineNumber()" />
        <xsl:text> M07&#10;</xsl:text>

        <xsl:text>G01</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Bevel-Parameters/Angle">
            <xsl:text> A</xsl:text>
			<xsl:value-of select="format-number(child::Block-after/Bevel-Parameters/Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:text> A0</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:text> C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>

        <xsl:if test="name(child::*[2])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[2]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="name(child::*[3])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[3]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:if test="name(child::*[4])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[4]" />
          </xsl:call-template>
        </xsl:if>

        <xsl:text>M34&#10;</xsl:text>

      </xsl:otherwise>
    </xsl:choose>

    <xsl:apply-templates />

    <xsl:text>(... End of START042/GC-SkewRadialMF macro ...)&#10;</xsl:text>
  </xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='Start041'][Block-after/Tool='Skew']">
    <xsl:text>(... Start of START041/GC-SKEW macro ...)&#10;</xsl:text>

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=3)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro START041&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[1])='Empty-Element'">
        <xsl:text>Error: Erstes Anschnitt-Element von Makro START041 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[2])='Empty-Element'">
        <xsl:text>Error: Zweites Anschnitt-Element von Makro START041 ist leer&#10;</xsl:text>
      </xsl:when>

      <xsl:otherwise>

        <xsl:value-of select="MCS-Scripts:InitiateContourBorders()" />

        <xsl:if test="/Root/Parameter[@ID='0x0071']/@value='1'">
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(child::Offset-after/*[self::Line or self::Arch])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::*[self::Line or self::Arch or self::Macro])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::Macro[1]/Offset-before/*[self::Line or self::Arch])" />
        </xsl:if>

        <xsl:variable name="SpeedFactor" select="MCS-Scripts:GetContourDiameter(/Root/Parameter[@ID='0x0072']/@value, /Root/Parameter[@ID='0x0073']/@value, /Root/Parameter[@ID='0x0074']/@value, /Root/Parameter[@ID='0x0075']/@value)" />

        <xsl:text>G90 G00 A0 C0&#10;</xsl:text>
        <xsl:text>#TIME 0.1&#10;</xsl:text>

		<xsl:call-template name="SelectMacro">
			<xsl:with-param name="_Material" select="../Material/@type" />
			<xsl:with-param name="_Thickness" select="../Thickness/@value" />
		</xsl:call-template>

        <xsl:value-of select="MCS-Scripts:MakeMultiLines(../Parameter[@ID='0x0102']/@value)" />

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M32&#10;</xsl:text>

        <xsl:text>G00 X</xsl:text>
		<xsl:value-of select="format-number(child::*[2]/Point-B/X, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> Y</xsl:text>
		<xsl:value-of select="format-number(child::*[2]/Point-B/Y, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> A0 C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M22&#10;</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Speed">
            <xsl:text>M94 F</xsl:text>
            <xsl:value-of select="format-number(child::Block-after/Speed*$SpeedFactor, '#.0')" />
            <xsl:text>&#10;</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>M93&#10;</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:call-template name="TemplateMove" >
          <xsl:with-param name="ThisX" select="child::*[1]//Point-B/X" />
          <xsl:with-param name="ThisY" select="child::*[1]//Point-B/Y" />
        </xsl:call-template>

        <xsl:if test="child::Block-after/Amperage">
          <xsl:text>V.E.CURRENT=</xsl:text>
          <xsl:value-of select="child::Block-after/Amperage" />
          <xsl:text>&#10;</xsl:text>
        </xsl:if>

        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G261&#10;</xsl:text>
        </xsl:if>

        <xsl:text>N</xsl:text>
        <xsl:value-of select="MCS-Scripts:GetLineNumber()" />
        <xsl:text> M07&#10;</xsl:text>

        <xsl:text>G01</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Bevel-Parameters/Angle">
            <xsl:text> A</xsl:text>
			<xsl:value-of select="format-number(child::Block-after/Bevel-Parameters/Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:text> A0</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:text> C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>

        <xsl:if test="name(child::*[2])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[2]" />
          </xsl:call-template>
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:if test="name(child::*[3])='Arch'">
      <xsl:call-template name="TemplateArch">
        <xsl:with-param name="ThisArch" select="child::*[3]" />
      </xsl:call-template>
    </xsl:if>

    <xsl:text>M34&#10;</xsl:text>

    <xsl:text>#CAXTRACK ON [ANGLIMIT 5]&#10;</xsl:text>

    <xsl:if test="name(child::Offset-after/*[self::Arch][1])='Arch'">
      <xsl:call-template name="TemplateArch">
        <xsl:with-param name="ThisArch" select="child::Offset-after/*[self::Arch][1]" />
      </xsl:call-template>
    </xsl:if>

    <xsl:text>(... End of START041/GC-SKEW macro ...)&#10;</xsl:text>
  </xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='Start042'][Block-after/Tool='Skew']">
    <xsl:text>(... Start of START042/GC-SKEW macro ...)&#10;</xsl:text>

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=4)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro START042&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[1])='Empty-Element'">
        <xsl:text>Error: Erstes Anschnitt-Element von Makro START042 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[2])='Empty-Element'">
        <xsl:text>Error: Zweites Anschnitt-Element von Makro START042 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[3])='Empty-Element'">
        <xsl:text>Error: Drittes Anschnitt-Element von Makro START042 ist leer&#10;</xsl:text>
      </xsl:when>

      <xsl:otherwise>

        <xsl:value-of select="MCS-Scripts:InitiateContourBorders()" />

        <xsl:if test="/Root/Parameter[@ID='0x0071']/@value='1'">
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(child::Offset-after/*[self::Line or self::Arch])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::*[self::Line or self::Arch or self::Macro])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::Macro[1]/Offset-before/*[self::Line or self::Arch])" />
        </xsl:if>

        <xsl:variable name="SpeedFactor" select="MCS-Scripts:GetContourDiameter(/Root/Parameter[@ID='0x0072']/@value, /Root/Parameter[@ID='0x0073']/@value, /Root/Parameter[@ID='0x0074']/@value, /Root/Parameter[@ID='0x0075']/@value)" />

        <xsl:text>G90 G00 A0 C0&#10;</xsl:text>
        <xsl:text>#TIME 0.1&#10;</xsl:text>

		<xsl:call-template name="SelectMacro">
			<xsl:with-param name="_Material" select="../Material/@type" />
			<xsl:with-param name="_Thickness" select="../Thickness/@value" />
		</xsl:call-template>

        <xsl:value-of select="MCS-Scripts:MakeMultiLines(../Parameter[@ID='0x0102']/@value)" />

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M32&#10;</xsl:text>

        <xsl:text>G00 X</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/X, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> Y</xsl:text>
		<xsl:value-of select="format-number(child::*[1]/Point-A/Y, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
        <xsl:text> A0 C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>
        <xsl:text>M22&#10;</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Speed">
            <xsl:text>M94 F</xsl:text>
            <xsl:value-of select="format-number(child::Block-after/Speed*$SpeedFactor, '#.0')" />
            <xsl:text>&#10;</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>M93&#10;</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:call-template name="TemplateMove" >
          <xsl:with-param name="ThisX" select="child::*[1]//Point-B/X" />
          <xsl:with-param name="ThisY" select="child::*[1]//Point-B/Y" />
        </xsl:call-template>

        <xsl:if test="child::Block-after/Amperage">
          <xsl:text>V.E.CURRENT=</xsl:text>
          <xsl:value-of select="child::Block-after/Amperage" />
          <xsl:text>&#10;</xsl:text>
        </xsl:if>

        <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
          <xsl:text>G261&#10;</xsl:text>
        </xsl:if>

        <xsl:text>N</xsl:text>
        <xsl:value-of select="MCS-Scripts:GetLineNumber()" />
        <xsl:text> M07&#10;</xsl:text>

        <xsl:text>G01</xsl:text>

        <xsl:choose>
          <xsl:when test="child::Block-after/Bevel-Parameters/Angle">
            <xsl:text> A</xsl:text>
			<xsl:value-of select="format-number(child::Block-after/Bevel-Parameters/Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:text> A0</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:text> C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-after/*[self::Line or self::Arch])=0)">
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-after/*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-after/*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-after/*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(following::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(following::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(following::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(following::*[self::Line or self::Arch][1], 'For-Point-A')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>

        <xsl:if test="name(child::*[2])='Arch'">
          <xsl:call-template name="TemplateArch">
            <xsl:with-param name="ThisArch" select="child::*[2]" />
          </xsl:call-template>
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:if test="name(child::*[3])='Arch'">
      <xsl:call-template name="TemplateArch">
        <xsl:with-param name="ThisArch" select="child::*[3]" />
      </xsl:call-template>
    </xsl:if>
    
    <xsl:if test="name(child::*[4])='Arch'">
      <xsl:call-template name="TemplateArch">
        <xsl:with-param name="ThisArch" select="child::*[4]" />
      </xsl:call-template>
    </xsl:if>

    <xsl:text>M34&#10;</xsl:text>

    <xsl:text>#CAXTRACK ON [ANGLIMIT 5]&#10;</xsl:text>

    <xsl:if test="name(child::Offset-after/*[self::Arch][1])='Arch'">
      <xsl:call-template name="TemplateArch">
        <xsl:with-param name="ThisArch" select="child::Offset-after/*[self::Arch][1]" />
      </xsl:call-template>
    </xsl:if>

    <xsl:text>(... End of START042/GC-SKEW macro ...)&#10;</xsl:text>
  </xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='End002'][Block-before/Tool='SkewRadialOF']">
    <xsl:text>(... Start of END02/GC-SkewRadialOF macro ...)&#10;</xsl:text>
    <xsl:text>M50&#10;</xsl:text>

    <xsl:apply-templates />

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=1)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro END002&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[3])='Empty-Element'">
        <xsl:text>Error: Erstes Element von Makro END002 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:otherwise>


        <xsl:call-template name="TemplateArch">
          <xsl:with-param name="ThisArch" select="child::*[3]" />
        </xsl:call-template>

        <xsl:text>M08&#10;</xsl:text>
        <xsl:if test="/Root/Parameter[@ID='0x0041']/@value='1'">
          <xsl:text>G260&#10;</xsl:text>
        </xsl:if>
        <xsl:text>M51&#10;</xsl:text>

        <xsl:if test="child::Block-before/Speed">
          <xsl:text>M93&#10;</xsl:text>
        </xsl:if>

        <xsl:text>G90 G00 A0 C0&#10;</xsl:text>
        <xsl:text>#TIME 0.1&#10;</xsl:text>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:text>(... End of END02/GC-SkewRadialOF macro ...)&#10;</xsl:text>
  </xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='End002'][Block-before/Tool='SkewRadialMF']">
    <xsl:text>(... Start of END02/GC-SkewRadialMF macro ...)&#10;</xsl:text>
    <xsl:text>M50&#10;</xsl:text>

    <xsl:apply-templates />

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=1)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro END002&#10;</xsl:text>
      </xsl:when>
      <xsl:when test="name(child::*[3])='Empty-Element'">
        <xsl:text>Error: Erstes Element von Makro END002 ist leer&#10;</xsl:text>
      </xsl:when>
      <xsl:otherwise>


        <xsl:call-template name="TemplateArch">
          <xsl:with-param name="ThisArch" select="child::*[3]" />
        </xsl:call-template>

        <xsl:text>M08&#10;</xsl:text>
        <xsl:if test="/Root/Parameter[@ID='0x0041']/@value='1'">
          <xsl:text>G260&#10;</xsl:text>
        </xsl:if>
        <xsl:text>M51&#10;</xsl:text>

        <xsl:if test="child::Block-before/Speed">
          <xsl:text>M93&#10;</xsl:text>
        </xsl:if>

        <xsl:text>G90 G00 A0 C0&#10;</xsl:text>
        <xsl:text>#TIME 0.1&#10;</xsl:text>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:text>(... End of END02/GC-SkewRadialMF macro ...)&#10;</xsl:text>
  </xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='End002'][Block-before/Tool='Skew']">
		<xsl:text>(... Start of END02/GC-SKEW macro ...)&#10;</xsl:text>
		<xsl:text>M50&#10;</xsl:text>

		<xsl:apply-templates />

		<xsl:choose>
			<xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=1)">
				<xsl:text>Error: Falsche Anzahl Elemente fuer Makro END002&#10;</xsl:text>
			</xsl:when>
			<xsl:when test="name(child::*[3])='Empty-Element'">
				<xsl:text>Error: Erstes Element von Makro END002 ist leer&#10;</xsl:text>
			</xsl:when>
			<xsl:otherwise>

				<xsl:text>#CAXTRACK OFF [ANGPOS </xsl:text>

				<xsl:choose>
					<xsl:when test="not(count(child::Offset-before/*[self::Line or self::Arch])=0)">
						<xsl:variable name="NumberOffsetElements" select="count(child::Offset-before/*[self::Line or self::Arch])" />

						<xsl:if test="name(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])='Line'">
							<xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])" />
						</xsl:if>
						<xsl:if test="name(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])='Arch'">
							<xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements], 'For-Point-B')" />
						</xsl:if>
					</xsl:when>

					<xsl:when test="not(count(preceding::*[self::Line or self::Arch])=0)">
						<xsl:if test="name(preceding::*[self::Line or self::Arch][1])='Line'">
							<xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(preceding::*[self::Line or self::Arch][1])" />
						</xsl:if>
						<xsl:if test="name(preceding::*[self::Line or self::Arch][1])='Arch'">
							<xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(preceding::*[self::Line or self::Arch][1], 'For-Point-B')" />
						</xsl:if>
					</xsl:when>
				</xsl:choose>

				<xsl:text>]&#10;</xsl:text>

				<xsl:call-template name="TemplateArch">
					<xsl:with-param name="ThisArch" select="child::*[3]" />
				</xsl:call-template>

				<xsl:text>M08&#10;</xsl:text>
                <xsl:if test="/Root/Parameter[@ID='0x0041']/@value='1'">
                  <xsl:text>G260&#10;</xsl:text>
                </xsl:if>
				<xsl:text>M51&#10;</xsl:text>

				<xsl:if test="child::Block-before/Speed">
					<xsl:text>M93&#10;</xsl:text>
				</xsl:if>

                <xsl:text>G90 G00 A0 C0&#10;</xsl:text>
                <xsl:text>#TIME 0.1&#10;</xsl:text>
			</xsl:otherwise>
		</xsl:choose>

		<xsl:text>(... End of END02/GC-SKEW macro ...)&#10;</xsl:text>
	</xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='Join011'][Block-before/Tool='SkewRadialOF' and Block-after/Tool='SkewRadialOF']">

    <xsl:apply-templates select="Offset-before" />

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=1)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro JOIN011&#10;</xsl:text>
      </xsl:when>
      <xsl:otherwise>

        <xsl:value-of select="MCS-Scripts:InitiateContourBorders()" />

        <xsl:if test="/Root/Parameter[@ID='0x0071']/@value='1'">
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(child::Offset-after/*[self::Line or self::Arch])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::*[self::Line or self::Arch or self::Macro])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::Macro[1]/Offset-before/*[self::Line or self::Arch])" />
        </xsl:if>

        <xsl:variable name="SpeedFactor" select="MCS-Scripts:GetContourDiameter(/Root/Parameter[@ID='0x0072']/@value, /Root/Parameter[@ID='0x0073']/@value, /Root/Parameter[@ID='0x0074']/@value, /Root/Parameter[@ID='0x0075']/@value)" />

        <xsl:choose>
          <xsl:when test="child::Block-after/Bevel-Parameters/Angle">
            <xsl:text> A</xsl:text>
			<xsl:value-of select="format-number(child::Block-after/Bevel-Parameters/Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:text> A0</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:text> C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-before/*[self::Line or self::Arch])=0)">
            <xsl:variable name="NumberOffsetElements" select="count(child::Offset-before/*[self::Line or self::Arch])" />

            <xsl:if test="name(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements], 'For-Point-B')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(preceding::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(preceding::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(preceding::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(preceding::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(preceding::*[self::Line or self::Arch][1], 'For-Point-B')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>

      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>
  
  <xsl:template match="Root/Macro[@step='working'][@name='Join011'][Block-before/Tool='SkewRadialMF' and Block-after/Tool='SkewRadialMF']">

    <xsl:apply-templates select="Offset-before" />

    <xsl:choose>
      <xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=1)">
        <xsl:text>Error: Falsche Anzahl Elemente fuer Makro JOIN011&#10;</xsl:text>
      </xsl:when>
      <xsl:otherwise>

        <xsl:value-of select="MCS-Scripts:InitiateContourBorders()" />

        <xsl:if test="/Root/Parameter[@ID='0x0071']/@value='1'">
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(child::Offset-after/*[self::Line or self::Arch])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::*[self::Line or self::Arch or self::Macro])" />
          <xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::Macro[1]/Offset-before/*[self::Line or self::Arch])" />
        </xsl:if>

        <xsl:variable name="SpeedFactor" select="MCS-Scripts:GetContourDiameter(/Root/Parameter[@ID='0x0072']/@value, /Root/Parameter[@ID='0x0073']/@value, /Root/Parameter[@ID='0x0074']/@value, /Root/Parameter[@ID='0x0075']/@value)" />

        <xsl:choose>
          <xsl:when test="child::Block-after/Bevel-Parameters/Angle">
            <xsl:text> A</xsl:text>
			<xsl:value-of select="format-number(child::Block-after/Bevel-Parameters/Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
          </xsl:when>
          <xsl:otherwise>
            <xsl:text> A0</xsl:text>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:text> C</xsl:text>

        <xsl:choose>
          <xsl:when test="not(count(child::Offset-before/*[self::Line or self::Arch])=0)">
            <xsl:variable name="NumberOffsetElements" select="count(child::Offset-before/*[self::Line or self::Arch])" />

            <xsl:if test="name(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])" />
            </xsl:if>
            <xsl:if test="name(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements], 'For-Point-B')" />
            </xsl:if>
          </xsl:when>

          <xsl:when test="not(count(preceding::*[self::Line or self::Arch])=0)">
            <xsl:if test="name(preceding::*[self::Line or self::Arch][1])='Line'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(preceding::*[self::Line or self::Arch][1])" />
            </xsl:if>
            <xsl:if test="name(preceding::*[self::Line or self::Arch][1])='Arch'">
              <xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(preceding::*[self::Line or self::Arch][1], 'For-Point-B')" />
            </xsl:if>
          </xsl:when>
        </xsl:choose>

        <xsl:text>&#10;</xsl:text>

      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template match="Root/Macro[@step='working'][@name='Join011'][Block-before/Tool='Skew' and Block-after/Tool='Skew']">
		<xsl:text>(... Start of JOIN11/GC-SKEW to GC-SKEW macro ...)&#10;</xsl:text>
		<xsl:text>M50&#10;</xsl:text>

		<xsl:apply-templates select="Offset-before" />

		<xsl:choose>
			<xsl:when test="not(count(child::*[self::Line or self::Arch or self::Empty-Element])=1)">
				<xsl:text>Error: Falsche Anzahl Elemente fuer Makro JOIN011&#10;</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				
				<xsl:value-of select="MCS-Scripts:InitiateContourBorders()" />

				<xsl:if test="/Root/Parameter[@ID='0x0071']/@value='1'">
					<xsl:value-of select="MCS-Scripts:UpdateContourBorders(child::Offset-after/*[self::Line or self::Arch])" />
					<xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::*[self::Line or self::Arch or self::Macro])" />
					<xsl:value-of select="MCS-Scripts:UpdateContourBorders(following-sibling::Macro[1]/Offset-before/*[self::Line or self::Arch])" />
				</xsl:if>

				<xsl:variable name="SpeedFactor" select="MCS-Scripts:GetContourDiameter(/Root/Parameter[@ID='0x0072']/@value, /Root/Parameter[@ID='0x0073']/@value, /Root/Parameter[@ID='0x0074']/@value, /Root/Parameter[@ID='0x0075']/@value)" />

				<xsl:text>#CAXTRACK OFF [ANGPOS </xsl:text>

				<xsl:choose>
					<xsl:when test="not(count(child::Offset-before/*[self::Line or self::Arch])=0)">
						<xsl:variable name="NumberOffsetElements" select="count(child::Offset-before/*[self::Line or self::Arch])" />

						<xsl:if test="name(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])='Line'">
							<xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])" />
						</xsl:if>
						<xsl:if test="name(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements])='Arch'">
							<xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(child::Offset-before/*[self::Line or self::Arch][$NumberOffsetElements], 'For-Point-B')" />
						</xsl:if>
					</xsl:when>

					<xsl:when test="not(count(preceding::*[self::Line or self::Arch])=0)">
						<xsl:if test="name(preceding::*[self::Line or self::Arch][1])='Line'">
							<xsl:value-of select="MCS-Scripts:GetRotationAngleForLine(preceding::*[self::Line or self::Arch][1])" />
						</xsl:if>
						<xsl:if test="name(preceding::*[self::Line or self::Arch][1])='Arch'">
							<xsl:value-of select="MCS-Scripts:GetRotationAngleForArch(preceding::*[self::Line or self::Arch][1], 'For-Point-B')" />
						</xsl:if>
					</xsl:when>
				</xsl:choose>

				<xsl:text>]&#10;</xsl:text>

                <xsl:if test="/Root/Parameter[@ID='0x0041']/@value='1'">
                  <xsl:text>G260&#10;</xsl:text>
                </xsl:if>
				<xsl:text>G01</xsl:text>

				<xsl:if test="name(child::*[3])='Line'">
					<xsl:text> X</xsl:text>
					<xsl:value-of select="child::*[3]/Point-B/X" />
					<xsl:text> Y</xsl:text>
					<xsl:value-of select="child::*[3]/Point-B/Y" />
				</xsl:if>

				<xsl:choose>
					<xsl:when test="child::Block-after/Bevel-Parameters/Angle">
						<xsl:text> A</xsl:text>
						<xsl:value-of select="format-number(child::Block-after/Bevel-Parameters/Angle, MCS-Scripts:GetDigitsNumber(/Root/Parameter[@ID='0x0003']/@value))" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:text> A0</xsl:text>
					</xsl:otherwise>
				</xsl:choose>

				<xsl:text>&#10;</xsl:text>
                <xsl:if test="/Root/Parameter[@ID='0x0042']/@value='1'">
                  <xsl:text>G261&#10;</xsl:text>
                </xsl:if>
				<xsl:text>#CAXTRACK ON [ANGLIMIT 5]&#10;</xsl:text>

				<xsl:choose>
                    <xsl:when test="child::Block-after/Speed">
                        <xsl:text>M94 F</xsl:text>
						<xsl:value-of select="format-number(child::Block-after/Speed*$SpeedFactor, '#.0')" />
						<xsl:text>&#10;</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>M93&#10;</xsl:text>
					</xsl:otherwise>
				</xsl:choose>

				<xsl:if test="child::Block-after/Amperage">
					<xsl:text>V.E.CURRENT=</xsl:text>
					<xsl:value-of select="child::Block-after/Amperage" />
					<xsl:text>&#10;</xsl:text>
				</xsl:if>

			</xsl:otherwise>
		</xsl:choose>

		<xsl:apply-templates select="Offset-after" />

		<xsl:text>M34&#10;</xsl:text>
		<xsl:text>M51&#10;</xsl:text>

		<xsl:text>(... End of JOIN11/GC-SKEW to GC-SKEW macro ...)&#10;</xsl:text>
	</xsl:template>




</xsl:stylesheet>
<!-- Stylus Studio meta-information - (c) 2004-2008. Progress Software Corporation. All rights reserved.

<metaInformation>
	<scenarios>
		<scenario default="yes" name="Scenario1" userelativepaths="yes" externalpreview="no" url="..\..\..\..\NestPlan_1.TXT.xml" htmlbaseurl="" outputurl="" processortype="msxmldotnet" useresolver="no" profilemode="0" profiledepth="" profilelength=""
		          urlprofilexml="" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext="" validateoutput="no" validator="internal"
		          customvalidator="">
			<advancedProp name="sInitialMode" value=""/>
			<advancedProp name="bXsltOneIsOkay" value="true"/>
			<advancedProp name="bSchemaAware" value="true"/>
			<advancedProp name="bXml11" value="false"/>
			<advancedProp name="iValidation" value="0"/>
			<advancedProp name="bExtensions" value="true"/>
			<advancedProp name="iWhitespace" value="0"/>
			<advancedProp name="sInitialTemplate" value=""/>
			<advancedProp name="bTinyTree" value="true"/>
			<advancedProp name="bWarnings" value="true"/>
			<advancedProp name="bUseDTD" value="false"/>
			<advancedProp name="iErrorHandling" value="fatal"/>
		</scenario>
	</scenarios>
	<MapperMetaTag>
		<MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no"/>
		<MapperBlockPosition></MapperBlockPosition>
		<TemplateContext></TemplateContext>
		<MapperFilter side="source"></MapperFilter>
	</MapperMetaTag>
</metaInformation>
-->